@@ -38,7 +38,7 @@ logger_config = {
     ]
 }
 
-handlers = ['console']
+handlers = []
 
 default_config = {
     "version": 1,
